function t1 ()
{
  1
}

function t2 ()
{
  return
}

function t3 ()
{
  return a + b
}

function t4 ()
{
  return
  a + b
}

function t5 ()
{
  i
  ++i;
}

function t6 ()
{
  i
  --i;
}

t3 ()

{ 1
    2 } 3


/*
Local variables:
mode: c
End:
*/
